@@ -1,5 +1,5 @@
 package Mail::DMARC::PurePerl;
-our $VERSION = '1.20141030'; # VERSION
+our $VERSION = '1.20141119'; # VERSION
 use strict;
 use warnings;
 
@@ -38,8 +38,17 @@ sub validate {
 
     $self->is_dkim_aligned;   # 11.2.3. DKIM signature verification checks
     $self->is_spf_aligned;    # 11.2.4. SPF validation checks
-    $self->is_aligned()       # 11.2.5. identifier alignment checks
-        and return $self->result;
+    my $aligned = $self->is_aligned(); # 11.2.5. identifier alignment checks
+
+    if ($self->config->{report_store}{auto_save}) {
+        my $pol;
+        eval { $pol = $self->result->published; };
+        if ( $pol && $self->has_valid_reporting_uri($pol->rua) ) {
+            eval { $self->save_aggregate(); };
+        };
+    }
+
+    return $self->result if $aligned;
 
     my $effective_p
         = $self->is_subdomain && defined $policy->sp
@@ -545,7 +554,7 @@ Mail::DMARC::PurePerl - Pure Perl implementation of DMARC
 
 =head1 VERSION
 
-version 1.20141030
+version 1.20141119
 
 =head1 METHODS
 
